@@ -147,6 +147,7 @@ print.summary.GridTopology = function(x, ...) {
 
 as.SpatialPolygons.GridTopology <- function(grd, proj4string=CRS(as.character(NA)))
 {
+	coordnam = names(grd@cellcentre.offset)
 	grd_crds <- coordinates(grd)
 	IDs <- IDvaluesGridTopology(grd)
 	nPolygons <- nrow(grd_crds)
@@ -160,12 +161,18 @@ as.SpatialPolygons.GridTopology <- function(grd, proj4string=CRS(as.character(NA
 		yi <- grd_crds[i,2]
 		x <- c(xi-cS2x, xi-cS2x, xi+cS2x, xi+cS2x, xi-cS2x)
 		y <- c(yi-cS2y, yi+cS2y, yi+cS2y, yi-cS2y, yi-cS2y)
-		Srl[[i]] <- Polygons(list(Polygon(coords=cbind(x, y)
-#, proj4string=proj4string
-)), ID=IDs[i])
-                comment(Srl[[i]]) <- "0"
+		coords = cbind(x, y)
+		if (!is.null(coordnam))
+			dimnames(coords) = list(NULL, coordnam)
+		else
+			rownames(coords) = NULL
+		Srl[[i]] <- Polygons(list(Polygon(coords = coords)), ID = IDs[i])
+		comment(Srl[[i]]) <- "0"
 	}
-	res <- SpatialPolygons(Srl, proj4string=proj4string)
+	res <- SpatialPolygons(Srl, proj4string = proj4string)
+	# address https://github.com/edzer/sp/issues/3:
+	if (!is.null(coordnam))
+		dimnames(res@bbox)[[1]] = coordnam
 	res
 }
 setAs("GridTopology", "SpatialPolygons", function(from)
